bayespy.inference.vmp.nodes.deterministic.Deterministic.get_shape
=================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.deterministic

.. automethod:: Deterministic.get_shape